@@ -1,4 +1,4 @@
-use super::result;
+use crate::result;
 
 pub fn deserialize(bytes: &[u8]) -> result::Result<u128> {
     let mut res = 0;
@@ -6,7 +6,7 @@ pub fn deserialize(bytes: &[u8]) -> result::Result<u128> {
     if bytes.len() == 0 {
         Ok(res)
     } else if bytes.len() > 16 {
-        result::Error::quick(format!(
+        result::Error::as_err(format!(
             "expected bytes.len() ({}) to be under 17 or equals to 16",
             bytes.len()
         ))
