@@ -15,7 +15,7 @@ impl Error {
         }
     }
 
-    pub fn quick<S: AsRef<str>, T>(msg: S) -> Result<T> {
+    pub fn as_err<S: AsRef<str>, T>(msg: S) -> Result<T> {
         Error::new(msg.as_ref()).to_err()
     }
 
@@ -23,6 +23,10 @@ impl Error {
         Err(self.clone())
     }
 
+    pub fn with_title(&self, title: &str) -> Self {
+        Error::new(format!("{}: {}", title, self.msg))
+    }
+
     pub unsafe fn panic(&self) -> ! {
         panic!("{}", self.msg);
     }
