@@ -1,6 +1,6 @@
-use super::int;
-use super::log;
-use super::result;
+use crate::int;
+use crate::log;
+use crate::result;
 
 #[test]
 fn test_log() {
